@@ -1,6 +1,6 @@
 from __future__ import division
 from collections import defaultdict
-
+import typing
 import random
 
 import numpy as np
@@ -8,12 +8,22 @@ import numpy as np
 from albumentations.augmentations.keypoints_utils import KeypointsProcessor
 from albumentations.core.serialization import SerializableMeta, get_shortest_class_fullname
 from albumentations.core.six import add_metaclass
-from albumentations.core.transforms_interface import DualTransform
-from albumentations.core.utils import format_args, Params
+from albumentations.core.transforms_interface import DualTransform, BasicTransform
+from albumentations.core.utils import format_args, Params, get_shape
 from albumentations.augmentations.bbox_utils import BboxProcessor
-from albumentations.core.serialization import SERIALIZABLE_REGISTRY, instantiate_lambda
+from albumentations.core.serialization import SERIALIZABLE_REGISTRY, instantiate_nonserializable
 
-__all__ = ["Compose", "SomeOf", "OneOf", "OneOrOther", "BboxParams", "KeypointParams", "ReplayCompose", "Sequential"]
+__all__ = [
+    "BaseCompose",
+    "Compose",
+    "SomeOf",
+    "OneOf",
+    "OneOrOther",
+    "BboxParams",
+    "KeypointParams",
+    "ReplayCompose",
+    "Sequential",
+]
 
 
 REPR_INDENT_STEP = 2
@@ -92,6 +102,10 @@ class BaseCompose:
     def get_class_fullname(cls):
         return get_shortest_class_fullname(cls)
 
+    @classmethod
+    def is_serializable(cls):
+        return True
+
     def _to_dict(self):
         return {
             "__class_fullname__": self.get_class_fullname(),
@@ -160,41 +174,60 @@ class Compose(BaseCompose):
 
         self.add_targets(additional_targets)
 
+        self.is_check_args = True
+        self._disable_check_args_for_transforms(self.transforms.transforms)
+
+    @staticmethod
+    def _disable_check_args_for_transforms(transforms: typing.List[typing.Union[BaseCompose, BasicTransform]]):
+        for transform in transforms:
+            if isinstance(transform, BaseCompose):
+                Compose._disable_check_args_for_transforms(transform.transforms.transforms)
+            if isinstance(transform, Compose):
+                transform._disable_check_args()
+
+    def _disable_check_args(self):
+        self.is_check_args = False
+
     def __call__(self, *args, force_apply=False, **data):
         if args:
             raise KeyError("You have to pass data to augmentations as named arguments, for example: aug(image=image)")
-        self._check_args(**data)
+        if self.is_check_args:
+            self._check_args(**data)
         assert isinstance(force_apply, (bool, int)), "force_apply must have bool or int type"
         need_to_run = force_apply or random.random() < self.p
         for p in self.processors.values():
             p.ensure_data_valid(data)
         transforms = self.transforms if need_to_run else self.transforms.get_always_apply(self.transforms)
-        dual_start_end = transforms.start_end if self.processors else None
+
         check_each_transform = any(
             getattr(item.params, "check_each_transform", False) for item in self.processors.values()
         )
 
-        for idx, t in enumerate(transforms):
-            if dual_start_end is not None and idx == dual_start_end[0]:
-                for p in self.processors.values():
-                    p.preprocess(data)
+        for p in self.processors.values():
+            p.preprocess(data)
 
+        for idx, t in enumerate(transforms):
             data = t(force_apply=force_apply, **data)
 
-            if dual_start_end is not None and idx == dual_start_end[1]:
-                for p in self.processors.values():
-                    p.postprocess(data)
-            elif check_each_transform and isinstance(t, DualTransform):
-                rows, cols = data["image"].shape[:2]
-                for p in self.processors.values():
-                    if not getattr(p.params, "check_each_transform", False):
-                        continue
+            if check_each_transform:
+                data = self._check_data_post_transform(data)
 
-                    for data_name in p.data_fields:
-                        data[data_name] = p.filter(data[data_name], rows, cols)
+        for p in self.processors.values():
+            p.postprocess(data)
 
         return data
 
+    def _check_data_post_transform(self, data):
+        rows, cols = get_shape(data["image"])
+
+        for p in self.processors.values():
+            if not getattr(p.params, "check_each_transform", False):
+                continue
+
+            for data_name in p.data_fields:
+                data[data_name] = p.filter(data[data_name], rows, cols)
+        return data
+
     def _to_dict(self):
         dictionary = super(Compose, self)._to_dict()
         bbox_processor = self.processors.get("bboxes")
@@ -229,6 +262,7 @@ class Compose(BaseCompose):
     def _check_args(self, **kwargs):
         checked_single = ["image", "mask"]
         checked_multi = ["masks"]
+        check_bbox_param = ["bboxes"]
         # ["bboxes", "keypoints"] could be almost any type, no need to check them
         for data_name, data in kwargs.items():
             internal_data_name = self.additional_targets.get(data_name, data_name)
@@ -239,6 +273,8 @@ class Compose(BaseCompose):
                 if data:
                     if not isinstance(data[0], np.ndarray):
                         raise TypeError("{} must be list of numpy arrays".format(data_name))
+            if internal_data_name in check_bbox_param and self.processors.get("bboxes") is None:
+                raise ValueError("bbox_params must be specified for bbox transformations")
 
 
 class OneOf(BaseCompose):
@@ -400,7 +436,7 @@ class ReplayCompose(Compose):
         transform = transform_dict
         applied = transform["applied"]
         params = transform["params"]
-        lmbd = instantiate_lambda(transform, lambda_transforms)
+        lmbd = instantiate_nonserializable(transform, lambda_transforms)
         if lmbd:
             transform = lmbd
         else:
@@ -453,7 +489,7 @@ class BboxParams(Params):
                 `[x_min, y_min, x_max, y_max]`, e.g. [97, 12, 247, 212].
             The `albumentations` format
                 is like `pascal_voc`, but normalized,
-                in other words: [x_min, y_min, x_max, y_max]`, e.g. [0.2, 0.3, 0.4, 0.5].
+                in other words: `[x_min, y_min, x_max, y_max]`, e.g. [0.2, 0.3, 0.4, 0.5].
             The `yolo` format
                 `[x, y, width, height]`, e.g. [0.1, 0.2, 0.3, 0.4];
                 `x`, `y` - normalized bbox center; `width`, `height` - normalized bbox width and height.
