@@ -5,7 +5,9 @@ import numpy as np
 import pytest
 from numpy.testing import assert_array_almost_equal_nulp
 
+import albumentations as A
 import albumentations.augmentations.functional as F
+import albumentations.augmentations.geometric.functional as FGeometric
 from albumentations.augmentations.bbox_utils import filter_bboxes
 from tests.utils import convert_2d_to_target_format
 
@@ -109,14 +111,14 @@ def test_normalize_float():
 
 
 def test_compare_rotate_and_shift_scale_rotate(image):
-    rotated_img_1 = F.rotate(image, angle=60)
-    rotated_img_2 = F.shift_scale_rotate(image, angle=60, scale=1, dx=0, dy=0)
+    rotated_img_1 = FGeometric.rotate(image, angle=60)
+    rotated_img_2 = FGeometric.shift_scale_rotate(image, angle=60, scale=1, dx=0, dy=0)
     assert np.array_equal(rotated_img_1, rotated_img_2)
 
 
 def test_compare_rotate_float_and_shift_scale_rotate_float(float_image):
-    rotated_img_1 = F.rotate(float_image, angle=60)
-    rotated_img_2 = F.shift_scale_rotate(float_image, angle=60, scale=1, dx=0, dy=0)
+    rotated_img_1 = FGeometric.rotate(float_image, angle=60)
+    rotated_img_2 = FGeometric.shift_scale_rotate(float_image, angle=60, scale=1, dx=0, dy=0)
     assert np.array_equal(rotated_img_1, rotated_img_2)
 
 
@@ -125,7 +127,7 @@ def test_center_crop(target):
     img = np.array([[1, 1, 1, 1], [0, 1, 1, 1], [0, 0, 1, 1], [0, 0, 0, 1]], dtype=np.uint8)
     expected = np.array([[1, 1], [0, 1]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    cropped_img = F.center_crop(img, 2, 2)
+    cropped_img = A.center_crop(img, 2, 2)
     assert np.array_equal(cropped_img, expected)
 
 
@@ -136,14 +138,14 @@ def test_center_crop_float(target):
     )
     expected = np.array([[0.4, 0.4], [0.0, 0.4]], dtype=np.float32)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    cropped_img = F.center_crop(img, 2, 2)
+    cropped_img = A.center_crop(img, 2, 2)
     assert_array_almost_equal_nulp(cropped_img, expected)
 
 
 def test_center_crop_with_incorrectly_large_crop_size():
     img = np.ones((4, 4), dtype=np.uint8)
     with pytest.raises(ValueError) as exc_info:
-        F.center_crop(img, 8, 8)
+        A.center_crop(img, 8, 8)
     assert str(exc_info.value) == "Requested crop size (8, 8) is larger than the image size (4, 4)"
 
 
@@ -152,7 +154,7 @@ def test_random_crop(target):
     img = np.array([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12], [13, 14, 15, 16]], dtype=np.uint8)
     expected = np.array([[5, 6], [9, 10]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    cropped_img = F.random_crop(img, crop_height=2, crop_width=2, h_start=0.5, w_start=0)
+    cropped_img = A.random_crop(img, crop_height=2, crop_width=2, h_start=0.5, w_start=0)
     assert np.array_equal(cropped_img, expected)
 
 
@@ -164,14 +166,14 @@ def test_random_crop_float(target):
     )
     expected = np.array([[0.05, 0.06], [0.09, 0.10]], dtype=np.float32)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    cropped_img = F.random_crop(img, crop_height=2, crop_width=2, h_start=0.5, w_start=0)
+    cropped_img = A.random_crop(img, crop_height=2, crop_width=2, h_start=0.5, w_start=0)
     assert_array_almost_equal_nulp(cropped_img, expected)
 
 
 def test_random_crop_with_incorrectly_large_crop_size():
     img = np.ones((4, 4), dtype=np.uint8)
     with pytest.raises(ValueError) as exc_info:
-        F.random_crop(img, crop_height=8, crop_width=8, h_start=0, w_start=0)
+        A.random_crop(img, crop_height=8, crop_width=8, h_start=0, w_start=0)
     assert str(exc_info.value) == "Requested crop size (8, 8) is larger than the image size (4, 4)"
 
 
@@ -214,7 +216,7 @@ def test_rotate_from_shift_scale_rotate(target):
     img = np.array([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12], [13, 14, 15, 16]], dtype=np.uint8)
     expected = np.array([[0, 0, 0, 0], [4, 8, 12, 16], [3, 7, 11, 15], [2, 6, 10, 14]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    rotated_img = F.shift_scale_rotate(
+    rotated_img = FGeometric.shift_scale_rotate(
         img, angle=90, scale=1, dx=0, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert np.array_equal(rotated_img, expected)
@@ -231,7 +233,7 @@ def test_rotate_float_from_shift_scale_rotate(target):
         dtype=np.float32,
     )
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    rotated_img = F.shift_scale_rotate(
+    rotated_img = FGeometric.shift_scale_rotate(
         img, angle=90, scale=1, dx=0, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert_array_almost_equal_nulp(rotated_img, expected)
@@ -242,7 +244,7 @@ def test_scale_from_shift_scale_rotate(target):
     img = np.array([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12], [13, 14, 15, 16]], dtype=np.uint8)
     expected = np.array([[6, 7, 7, 8], [10, 11, 11, 12], [10, 11, 11, 12], [14, 15, 15, 16]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    scaled_img = F.shift_scale_rotate(
+    scaled_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=2, dx=0, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert np.array_equal(scaled_img, expected)
@@ -259,7 +261,7 @@ def test_scale_float_from_shift_scale_rotate(target):
         dtype=np.float32,
     )
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    scaled_img = F.shift_scale_rotate(
+    scaled_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=2, dx=0, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert_array_almost_equal_nulp(scaled_img, expected)
@@ -270,7 +272,7 @@ def test_shift_x_from_shift_scale_rotate(target):
     img = np.array([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12], [13, 14, 15, 16]], dtype=np.uint8)
     expected = np.array([[0, 0, 1, 2], [0, 0, 5, 6], [0, 0, 9, 10], [0, 0, 13, 14]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    shifted_along_x_img = F.shift_scale_rotate(
+    shifted_along_x_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=1, dx=0.5, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert np.array_equal(shifted_along_x_img, expected)
@@ -287,7 +289,7 @@ def test_shift_x_float_from_shift_scale_rotate(target):
         dtype=np.float32,
     )
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    shifted_along_x_img = F.shift_scale_rotate(
+    shifted_along_x_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=1, dx=0.5, dy=0, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert_array_almost_equal_nulp(shifted_along_x_img, expected)
@@ -298,7 +300,7 @@ def test_shift_y_from_shift_scale_rotate(target):
     img = np.array([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12], [13, 14, 15, 16]], dtype=np.uint8)
     expected = np.array([[0, 0, 0, 0], [0, 0, 0, 0], [1, 2, 3, 4], [5, 6, 7, 8]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    shifted_along_y_img = F.shift_scale_rotate(
+    shifted_along_y_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=1, dx=0, dy=0.5, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert np.array_equal(shifted_along_y_img, expected)
@@ -315,7 +317,7 @@ def test_shift_y_float_from_shift_scale_rotate(target):
         dtype=np.float32,
     )
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    shifted_along_y_img = F.shift_scale_rotate(
+    shifted_along_y_img = FGeometric.shift_scale_rotate(
         img, angle=0, scale=1, dx=0, dy=0.5, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_CONSTANT
     )
     assert_array_almost_equal_nulp(shifted_along_y_img, expected)
@@ -479,7 +481,7 @@ def test_scale(target):
     )
 
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    scaled = F.scale(img, scale=2, interpolation=cv2.INTER_LINEAR)
+    scaled = FGeometric.scale(img, scale=2, interpolation=cv2.INTER_LINEAR)
     assert np.array_equal(scaled, expected)
 
 
@@ -489,7 +491,7 @@ def test_longest_max_size(target):
     expected = np.array([[2, 3], [6, 7], [10, 11]], dtype=np.uint8)
 
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    scaled = F.longest_max_size(img, max_size=3, interpolation=cv2.INTER_LINEAR)
+    scaled = FGeometric.longest_max_size(img, max_size=3, interpolation=cv2.INTER_LINEAR)
     assert np.array_equal(scaled, expected)
 
 
@@ -501,7 +503,7 @@ def test_smallest_max_size(target):
     expected = np.array([[2, 4, 5, 7], [10, 11, 13, 14], [17, 19, 20, 22]], dtype=np.uint8)
 
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    scaled = F.smallest_max_size(img, max_size=3, interpolation=cv2.INTER_LINEAR)
+    scaled = FGeometric.smallest_max_size(img, max_size=3, interpolation=cv2.INTER_LINEAR)
     assert np.array_equal(scaled, expected)
 
 
@@ -520,7 +522,7 @@ def test_resize_default_interpolation(target):
     img = np.array([[1, 1, 1, 1], [2, 2, 2, 2], [3, 3, 3, 3], [4, 4, 4, 4]], dtype=np.uint8)
     expected = np.array([[2, 2], [4, 4]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    resized_img = F.resize(img, 2, 2)
+    resized_img = FGeometric.resize(img, 2, 2)
     height, width = resized_img.shape[:2]
     assert height == 2
     assert width == 2
@@ -532,7 +534,7 @@ def test_resize_nearest_interpolation(target):
     img = np.array([[1, 1, 1, 1], [2, 2, 2, 2], [3, 3, 3, 3], [4, 4, 4, 4]], dtype=np.uint8)
     expected = np.array([[1, 1], [3, 3]], dtype=np.uint8)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    resized_img = F.resize(img, 2, 2, interpolation=cv2.INTER_NEAREST)
+    resized_img = FGeometric.resize(img, 2, 2, interpolation=cv2.INTER_NEAREST)
     height, width = resized_img.shape[:2]
     assert height == 2
     assert width == 2
@@ -543,7 +545,7 @@ def test_resize_nearest_interpolation(target):
 def test_resize_different_height_and_width(target):
     img = np.ones((100, 100), dtype=np.uint8)
     img = convert_2d_to_target_format([img], target=target)
-    resized_img = F.resize(img, height=20, width=30)
+    resized_img = FGeometric.resize(img, height=20, width=30)
     height, width = resized_img.shape[:2]
     assert height == 20
     assert width == 30
@@ -559,7 +561,7 @@ def test_resize_default_interpolation_float(target):
     )
     expected = np.array([[0.15, 0.15], [0.35, 0.35]], dtype=np.float32)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    resized_img = F.resize(img, 2, 2)
+    resized_img = FGeometric.resize(img, 2, 2)
     height, width = resized_img.shape[:2]
     assert height == 2
     assert width == 2
@@ -573,7 +575,7 @@ def test_resize_nearest_interpolation_float(target):
     )
     expected = np.array([[0.1, 0.1], [0.3, 0.3]], dtype=np.float32)
     img, expected = convert_2d_to_target_format([img, expected], target=target)
-    resized_img = F.resize(img, 2, 2, interpolation=cv2.INTER_NEAREST)
+    resized_img = FGeometric.resize(img, 2, 2, interpolation=cv2.INTER_NEAREST)
     height, width = resized_img.shape[:2]
     assert height == 2
     assert width == 2
@@ -603,30 +605,30 @@ def test_bbox_flip(code, func):
 
 
 def test_crop_bbox_by_coords():
-    cropped_bbox = F.crop_bbox_by_coords((0.5, 0.2, 0.9, 0.7), (18, 18, 82, 82), 64, 64, 100, 100)
+    cropped_bbox = A.crop_bbox_by_coords((0.5, 0.2, 0.9, 0.7), (18, 18, 82, 82), 64, 64, 100, 100)
     assert cropped_bbox == (0.5, 0.03125, 1.125, 0.8125)
 
 
 def test_bbox_center_crop():
-    cropped_bbox = F.bbox_center_crop((0.5, 0.2, 0.9, 0.7), 64, 64, 100, 100)
+    cropped_bbox = A.bbox_center_crop((0.5, 0.2, 0.9, 0.7), 64, 64, 100, 100)
     assert cropped_bbox == (0.5, 0.03125, 1.125, 0.8125)
 
 
 def test_bbox_crop():
-    cropped_bbox = F.bbox_crop([0.5, 0.2, 0.9, 0.7], 24, 24, 64, 64, 100, 100)
+    cropped_bbox = A.bbox_crop([0.5, 0.2, 0.9, 0.7], 24, 24, 64, 64, 100, 100)
     assert cropped_bbox == (0.65, -0.1, 1.65, 1.15)
 
 
 def test_bbox_random_crop():
-    cropped_bbox = F.bbox_random_crop([0.5, 0.2, 0.9, 0.7], 80, 80, 0.2, 0.1, 100, 100)
+    cropped_bbox = A.bbox_random_crop([0.5, 0.2, 0.9, 0.7], 80, 80, 0.2, 0.1, 100, 100)
     assert cropped_bbox == (0.6, 0.2, 1.1, 0.825)
 
 
 def test_bbox_rot90():
-    assert F.bbox_rot90((0.1, 0.2, 0.3, 0.4), 0, 100, 200) == (0.1, 0.2, 0.3, 0.4)
-    assert F.bbox_rot90((0.1, 0.2, 0.3, 0.4), 1, 100, 200) == (0.2, 0.7, 0.4, 0.9)
-    assert F.bbox_rot90((0.1, 0.2, 0.3, 0.4), 2, 100, 200) == (0.7, 0.6, 0.9, 0.8)
-    assert F.bbox_rot90((0.1, 0.2, 0.3, 0.4), 3, 100, 200) == (0.6, 0.1, 0.8, 0.3)
+    assert FGeometric.bbox_rot90((0.1, 0.2, 0.3, 0.4), 0, 100, 200) == (0.1, 0.2, 0.3, 0.4)
+    assert FGeometric.bbox_rot90((0.1, 0.2, 0.3, 0.4), 1, 100, 200) == (0.2, 0.7, 0.4, 0.9)
+    assert FGeometric.bbox_rot90((0.1, 0.2, 0.3, 0.4), 2, 100, 200) == (0.7, 0.6, 0.9, 0.8)
+    assert FGeometric.bbox_rot90((0.1, 0.2, 0.3, 0.4), 3, 100, 200) == (0.6, 0.1, 0.8, 0.3)
 
 
 def test_bbox_transpose():
@@ -657,7 +659,7 @@ def test_fun_max_size():
     target_width = 256
 
     img = np.empty((330, 49), dtype=np.uint8)
-    out = F.smallest_max_size(img, target_width, interpolation=cv2.INTER_LINEAR)
+    out = FGeometric.smallest_max_size(img, target_width, interpolation=cv2.INTER_LINEAR)
 
     assert out.shape == (1724, target_width)
 
@@ -913,7 +915,7 @@ def test_maybe_process_in_chunks():
 
     for i in range(1, image.shape[-1] + 1):
         before = image[:, :, :i]
-        after = F.rotate(before, angle=1)
+        after = FGeometric.rotate(before, angle=1)
         assert before.shape == after.shape
 
 
