@@ -11,72 +11,42 @@ import albumentations as A
 import albumentations.augmentations.functional as F
 from albumentations.core.serialization import SERIALIZABLE_REGISTRY, shorten_class_name
 from albumentations.core.transforms_interface import ImageOnlyTransform
-from .conftest import torch_available, skipif_no_torch
-from .utils import OpenMock, set_seed
+from .conftest import skipif_no_torch
+from .utils import (
+    OpenMock,
+    set_seed,
+    get_transforms,
+    get_image_only_transforms,
+    get_dual_transforms,
+    check_all_augs_exists,
+)
 
 TEST_SEEDS = (0, 1, 42, 111, 9999)
 
 
 @pytest.mark.parametrize(
     ["augmentation_cls", "params"],
-    [
-        [A.ImageCompression, {}],
-        [A.JpegCompression, {}],
-        [A.HueSaturationValue, {}],
-        [A.RGBShift, {}],
-        [A.RandomBrightnessContrast, {}],
-        [A.Blur, {}],
-        [A.MotionBlur, {}],
-        [A.MedianBlur, {}],
-        [A.GaussianBlur, {}],
-        [A.GaussNoise, {}],
-        [A.CLAHE, {}],
-        [A.ChannelShuffle, {}],
-        [A.InvertImg, {}],
-        [A.RandomGamma, {}],
-        [A.ToGray, {}],
-        [A.Cutout, {}],
-        [A.CoarseDropout, {}],
-        [A.RandomSnow, {}],
-        [A.RandomRain, {}],
-        [A.RandomFog, {}],
-        [A.RandomSunFlare, {}],
-        [A.RandomShadow, {}],
-        [A.PadIfNeeded, {}],
-        [A.VerticalFlip, {}],
-        [A.HorizontalFlip, {}],
-        [A.Flip, {}],
-        [A.Transpose, {}],
-        [A.RandomRotate90, {}],
-        [A.Rotate, {}],
-        [A.SafeRotate, {}],
-        [A.ShiftScaleRotate, {}],
-        [A.OpticalDistortion, {}],
-        [A.GridDistortion, {}],
-        [A.ElasticTransform, {}],
-        [A.ToFloat, {}],
-        [A.Normalize, {}],
-        [A.RandomBrightness, {}],
-        [A.RandomContrast, {}],
-        [A.RandomScale, {}],
-        [A.RandomToneCurve, {}],
-        [A.SmallestMaxSize, {}],
-        [A.LongestMaxSize, {}],
-        [A.RandomGridShuffle, {}],
-        [A.Solarize, {}],
-        [A.Posterize, {}],
-        [A.Equalize, {}],
-        [A.Downscale, {}],
-        [A.MultiplicativeNoise, {}],
-        [A.ColorJitter, {}],
-        [A.Perspective, {}],
-        [A.Sharpen, {}],
-        [A.Emboss, {}],
-        [A.CropAndPad, {"px": 10}],
-        [A.Superpixels, {}],
-        [A.Affine, {}],
-        [A.PiecewiseAffine, {}],
-    ],
+    get_transforms(
+        custom_arguments={
+            A.Crop: {"y_min": 0, "y_max": 10, "x_min": 0, "x_max": 10},
+            A.CenterCrop: {"height": 10, "width": 10},
+            A.CropNonEmptyMaskIfExists: {"height": 10, "width": 10},
+            A.RandomCrop: {"height": 10, "width": 10},
+            A.RandomResizedCrop: {"height": 10, "width": 10},
+            A.RandomSizedCrop: {"min_max_height": (4, 8), "height": 10, "width": 10},
+            A.CropAndPad: {"px": 10},
+            A.Resize: {"height": 10, "width": 10},
+        },
+        except_augmentations={
+            A.RandomCropNearBBox,
+            A.RandomSizedBBoxSafeCrop,
+            A.FDA,
+            A.HistogramMatching,
+            A.PixelDistributionAdaptation,
+            A.Lambda,
+            A.TemplateTransform,
+        },
+    ),
 )
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
@@ -93,244 +63,273 @@ def test_augmentations_serialization(augmentation_cls, params, p, seed, image, m
     assert np.array_equal(aug_data["mask"], deserialized_aug_data["mask"])
 
 
-AUGMENTATION_CLS_PARAMS = (
+AUGMENTATION_CLS_PARAMS = [
     [
-        [
-            A.ImageCompression,
-            {
-                "quality_lower": 10,
-                "quality_upper": 80,
-                "compression_type": A.ImageCompression.ImageCompressionType.WEBP,
-            },
-        ],
-        [A.JpegCompression, {"quality_lower": 10, "quality_upper": 80}],
-        [A.HueSaturationValue, {"hue_shift_limit": 70, "sat_shift_limit": 95, "val_shift_limit": 55}],
-        [A.RGBShift, {"r_shift_limit": 70, "g_shift_limit": 80, "b_shift_limit": 40}],
-        [A.RandomBrightnessContrast, {"brightness_limit": 0.5, "contrast_limit": 0.8}],
-        [A.Blur, {"blur_limit": 3}],
-        [A.MotionBlur, {"blur_limit": 3}],
-        [A.MedianBlur, {"blur_limit": 3}],
-        [A.GaussianBlur, {"blur_limit": 3}],
-        [A.GaussNoise, {"var_limit": (20, 90), "mean": 10, "per_channel": False}],
-        [A.CLAHE, {"clip_limit": 2, "tile_grid_size": (12, 12)}],
-        [A.RandomGamma, {"gamma_limit": (10, 90)}],
-        [A.Cutout, {"num_holes": 4, "max_h_size": 4, "max_w_size": 4}],
-        [A.CoarseDropout, {"max_holes": 4, "max_height": 4, "max_width": 4}],
-        [A.RandomSnow, {"snow_point_lower": 0.2, "snow_point_upper": 0.4, "brightness_coeff": 4}],
-        [
-            A.RandomRain,
-            {
-                "slant_lower": -5,
-                "slant_upper": 5,
-                "drop_length": 15,
-                "drop_width": 2,
-                "drop_color": (100, 100, 100),
-                "blur_value": 3,
-                "brightness_coefficient": 0.5,
-                "rain_type": "heavy",
-            },
-        ],
-        [A.RandomFog, {"fog_coef_lower": 0.2, "fog_coef_upper": 0.8, "alpha_coef": 0.11}],
-        [
-            A.RandomSunFlare,
-            {
-                "flare_roi": (0.1, 0.1, 0.9, 0.6),
-                "angle_lower": 0.1,
-                "angle_upper": 0.95,
-                "num_flare_circles_lower": 7,
-                "num_flare_circles_upper": 11,
-                "src_radius": 300,
-                "src_color": (200, 200, 200),
-            },
-        ],
-        [
-            A.RandomShadow,
-            {
-                "shadow_roi": (0.1, 0.4, 0.9, 0.9),
-                "num_shadows_lower": 2,
-                "num_shadows_upper": 4,
-                "shadow_dimension": 8,
-            },
-        ],
-        [
-            A.PadIfNeeded,
-            {"min_height": 512, "min_width": 512, "border_mode": cv2.BORDER_CONSTANT, "value": (10, 10, 10)},
-        ],
-        [
-            A.Rotate,
-            {
-                "limit": 120,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.SafeRotate,
-            {
-                "limit": 120,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.ShiftScaleRotate,
-            {
-                "shift_limit": 0.2,
-                "scale_limit": 0.2,
-                "rotate_limit": 70,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.ShiftScaleRotate,
-            {
-                "shift_limit_x": 0.3,
-                "shift_limit_y": 0.4,
-                "scale_limit": 0.2,
-                "rotate_limit": 70,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.OpticalDistortion,
-            {
-                "distort_limit": 0.2,
-                "shift_limit": 0.2,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.GridDistortion,
-            {
-                "num_steps": 10,
-                "distort_limit": 0.5,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [
-            A.ElasticTransform,
-            {
-                "alpha": 2,
-                "sigma": 25,
-                "alpha_affine": 40,
-                "interpolation": cv2.INTER_CUBIC,
-                "border_mode": cv2.BORDER_CONSTANT,
-                "value": (10, 10, 10),
-            },
-        ],
-        [A.CenterCrop, {"height": 10, "width": 10}],
-        [A.RandomCrop, {"height": 10, "width": 10}],
-        [A.CropNonEmptyMaskIfExists, {"height": 10, "width": 10}],
-        [A.RandomSizedCrop, {"min_max_height": (4, 8), "height": 10, "width": 10}],
-        [A.Crop, {"x_max": 64, "y_max": 64}],
-        [A.ToFloat, {"max_value": 16536}],
-        [A.Normalize, {"mean": (0.385, 0.356, 0.306), "std": (0.129, 0.124, 0.125), "max_pixel_value": 100.0}],
-        [A.RandomBrightness, {"limit": 0.4}],
-        [A.RandomContrast, {"limit": 0.4}],
-        [A.RandomScale, {"scale_limit": 0.2, "interpolation": cv2.INTER_CUBIC}],
-        [A.Resize, {"height": 64, "width": 64}],
-        [A.SmallestMaxSize, {"max_size": 64, "interpolation": cv2.INTER_CUBIC}],
-        [A.LongestMaxSize, {"max_size": 128, "interpolation": cv2.INTER_CUBIC}],
-        [A.RandomGridShuffle, {"grid": (5, 5)}],
-        [A.Solarize, {"threshold": 32}],
-        [A.Posterize, {"num_bits": 1}],
-        [A.Equalize, {"mode": "pil", "by_channels": False}],
-        [A.MultiplicativeNoise, {"multiplier": (0.7, 2.3), "per_channel": True, "elementwise": True}],
-        [
-            A.ColorJitter,
-            {"brightness": [0.2, 0.3], "contrast": [0.7, 0.9], "saturation": [1.2, 1.7], "hue": [-0.2, 0.1]},
-        ],
-        [
-            A.Perspective,
-            {
-                "scale": 0.5,
-                "keep_size": False,
-                "pad_mode": cv2.BORDER_REFLECT_101,
-                "pad_val": 10,
-                "mask_pad_val": 100,
-                "fit_output": True,
-                "interpolation": cv2.INTER_CUBIC,
-            },
-        ],
-        [A.Sharpen, {"alpha": [0.2, 0.5], "lightness": [0.5, 1.0]}],
-        [A.Emboss, {"alpha": [0.2, 0.5], "strength": [0.5, 1.0]}],
-        [A.RandomToneCurve, {"scale": 0.2}],
-        [
-            A.CropAndPad,
-            {
-                "px": 10,
-                "keep_size": False,
-                "sample_independently": False,
-                "interpolation": cv2.INTER_CUBIC,
-                "pad_cval_mask": [10, 20, 30],
-                "pad_cval": [11, 12, 13],
-                "pad_mode": cv2.BORDER_REFLECT101,
-            },
-        ],
-        [
-            A.Superpixels,
-            {"p_replace": (0.5, 0.7), "n_segments": (20, 30), "max_size": 25, "interpolation": cv2.INTER_CUBIC},
-        ],
-        [
-            A.Affine,
-            {
-                "scale": 0.5,
-                "translate_percent": 0.7,
-                "translate_px": None,
-                "rotate": 33,
-                "shear": 21,
-                "interpolation": cv2.INTER_CUBIC,
-                "cval": 25,
-                "cval_mask": 1,
-                "mode": cv2.BORDER_REFLECT,
-                "fit_output": True,
-            },
-        ],
-        [
-            A.Affine,
-            {
-                "scale": {"x": [0.3, 0.5], "y": [0.1, 0.2]},
-                "translate_percent": None,
-                "translate_px": {"x": [10, 200], "y": [5, 101]},
-                "rotate": [333, 360],
-                "shear": {"x": [31, 38], "y": [41, 48]},
-                "interpolation": 3,
-                "cval": [10, 20, 30],
-                "cval_mask": 1,
-                "mode": cv2.BORDER_REFLECT,
-                "fit_output": True,
-            },
-        ],
-        [
-            A.PiecewiseAffine,
-            {
-                "scale": 0.33,
-                "nb_rows": (10, 20),
-                "nb_cols": 33,
-                "interpolation": 2,
-                "mask_interpolation": 1,
-                "cval": 10,
-                "cval_mask": 20,
-                "mode": "edge",
-                "absolute_scale": True,
-                "keypoints_threshold": 0.1,
-            },
-        ],
+        A.ImageCompression,
+        {
+            "quality_lower": 10,
+            "quality_upper": 80,
+            "compression_type": A.ImageCompression.ImageCompressionType.WEBP,
+        },
     ],
+    [A.JpegCompression, {"quality_lower": 10, "quality_upper": 80}],
+    [A.HueSaturationValue, {"hue_shift_limit": 70, "sat_shift_limit": 95, "val_shift_limit": 55}],
+    [A.RGBShift, {"r_shift_limit": 70, "g_shift_limit": 80, "b_shift_limit": 40}],
+    [A.RandomBrightnessContrast, {"brightness_limit": 0.5, "contrast_limit": 0.8}],
+    [A.Blur, {"blur_limit": 3}],
+    [A.MotionBlur, {"blur_limit": 3}],
+    [A.MedianBlur, {"blur_limit": 3}],
+    [A.GaussianBlur, {"blur_limit": 3}],
+    [A.GaussNoise, {"var_limit": (20, 90), "mean": 10, "per_channel": False}],
+    [A.CLAHE, {"clip_limit": 2, "tile_grid_size": (12, 12)}],
+    [A.RandomGamma, {"gamma_limit": (10, 90)}],
+    [A.Cutout, {"num_holes": 4, "max_h_size": 4, "max_w_size": 4}],
+    [A.CoarseDropout, {"max_holes": 4, "max_height": 4, "max_width": 4}],
+    [A.RandomSnow, {"snow_point_lower": 0.2, "snow_point_upper": 0.4, "brightness_coeff": 4}],
+    [
+        A.RandomRain,
+        {
+            "slant_lower": -5,
+            "slant_upper": 5,
+            "drop_length": 15,
+            "drop_width": 2,
+            "drop_color": (100, 100, 100),
+            "blur_value": 3,
+            "brightness_coefficient": 0.5,
+            "rain_type": "heavy",
+        },
+    ],
+    [A.RandomFog, {"fog_coef_lower": 0.2, "fog_coef_upper": 0.8, "alpha_coef": 0.11}],
+    [
+        A.RandomSunFlare,
+        {
+            "flare_roi": (0.1, 0.1, 0.9, 0.6),
+            "angle_lower": 0.1,
+            "angle_upper": 0.95,
+            "num_flare_circles_lower": 7,
+            "num_flare_circles_upper": 11,
+            "src_radius": 300,
+            "src_color": (200, 200, 200),
+        },
+    ],
+    [
+        A.RandomShadow,
+        {
+            "shadow_roi": (0.1, 0.4, 0.9, 0.9),
+            "num_shadows_lower": 2,
+            "num_shadows_upper": 4,
+            "shadow_dimension": 8,
+        },
+    ],
+    [
+        A.PadIfNeeded,
+        {"min_height": 512, "min_width": 512, "border_mode": cv2.BORDER_CONSTANT, "value": (10, 10, 10)},
+    ],
+    [
+        A.Rotate,
+        {
+            "limit": 120,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.SafeRotate,
+        {
+            "limit": 120,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.ShiftScaleRotate,
+        {
+            "shift_limit": 0.2,
+            "scale_limit": 0.2,
+            "rotate_limit": 70,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.ShiftScaleRotate,
+        {
+            "shift_limit_x": 0.3,
+            "shift_limit_y": 0.4,
+            "scale_limit": 0.2,
+            "rotate_limit": 70,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.OpticalDistortion,
+        {
+            "distort_limit": 0.2,
+            "shift_limit": 0.2,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.GridDistortion,
+        {
+            "num_steps": 10,
+            "distort_limit": 0.5,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [
+        A.ElasticTransform,
+        {
+            "alpha": 2,
+            "sigma": 25,
+            "alpha_affine": 40,
+            "interpolation": cv2.INTER_CUBIC,
+            "border_mode": cv2.BORDER_CONSTANT,
+            "value": (10, 10, 10),
+        },
+    ],
+    [A.CenterCrop, {"height": 10, "width": 10}],
+    [A.RandomCrop, {"height": 10, "width": 10}],
+    [A.CropNonEmptyMaskIfExists, {"height": 10, "width": 10}],
+    [A.RandomSizedCrop, {"min_max_height": (4, 8), "height": 10, "width": 10}],
+    [A.Crop, {"x_max": 64, "y_max": 64}],
+    [A.ToFloat, {"max_value": 16536}],
+    [A.Normalize, {"mean": (0.385, 0.356, 0.306), "std": (0.129, 0.124, 0.125), "max_pixel_value": 100.0}],
+    [A.RandomBrightness, {"limit": 0.4}],
+    [A.RandomContrast, {"limit": 0.4}],
+    [A.RandomScale, {"scale_limit": 0.2, "interpolation": cv2.INTER_CUBIC}],
+    [A.Resize, {"height": 64, "width": 64}],
+    [A.SmallestMaxSize, {"max_size": 64, "interpolation": cv2.INTER_CUBIC}],
+    [A.LongestMaxSize, {"max_size": 128, "interpolation": cv2.INTER_CUBIC}],
+    [A.RandomGridShuffle, {"grid": (5, 5)}],
+    [A.Solarize, {"threshold": 32}],
+    [A.Posterize, {"num_bits": 1}],
+    [A.Equalize, {"mode": "pil", "by_channels": False}],
+    [A.MultiplicativeNoise, {"multiplier": (0.7, 2.3), "per_channel": True, "elementwise": True}],
+    [
+        A.ColorJitter,
+        {"brightness": [0.2, 0.3], "contrast": [0.7, 0.9], "saturation": [1.2, 1.7], "hue": [-0.2, 0.1]},
+    ],
+    [
+        A.Perspective,
+        {
+            "scale": 0.5,
+            "keep_size": False,
+            "pad_mode": cv2.BORDER_REFLECT_101,
+            "pad_val": 10,
+            "mask_pad_val": 100,
+            "fit_output": True,
+            "interpolation": cv2.INTER_CUBIC,
+        },
+    ],
+    [A.Sharpen, {"alpha": [0.2, 0.5], "lightness": [0.5, 1.0]}],
+    [A.Emboss, {"alpha": [0.2, 0.5], "strength": [0.5, 1.0]}],
+    [A.RandomToneCurve, {"scale": 0.2}],
+    [
+        A.CropAndPad,
+        {
+            "px": 10,
+            "keep_size": False,
+            "sample_independently": False,
+            "interpolation": cv2.INTER_CUBIC,
+            "pad_cval_mask": [10, 20, 30],
+            "pad_cval": [11, 12, 13],
+            "pad_mode": cv2.BORDER_REFLECT101,
+        },
+    ],
+    [
+        A.Superpixels,
+        {"p_replace": (0.5, 0.7), "n_segments": (20, 30), "max_size": 25, "interpolation": cv2.INTER_CUBIC},
+    ],
+    [
+        A.Affine,
+        {
+            "scale": 0.5,
+            "translate_percent": 0.7,
+            "translate_px": None,
+            "rotate": 33,
+            "shear": 21,
+            "interpolation": cv2.INTER_CUBIC,
+            "cval": 25,
+            "cval_mask": 1,
+            "mode": cv2.BORDER_REFLECT,
+            "fit_output": True,
+        },
+    ],
+    [
+        A.Affine,
+        {
+            "scale": {"x": [0.3, 0.5], "y": [0.1, 0.2]},
+            "translate_percent": None,
+            "translate_px": {"x": [10, 200], "y": [5, 101]},
+            "rotate": [333, 360],
+            "shear": {"x": [31, 38], "y": [41, 48]},
+            "interpolation": 3,
+            "cval": [10, 20, 30],
+            "cval_mask": 1,
+            "mode": cv2.BORDER_REFLECT,
+            "fit_output": True,
+        },
+    ],
+    [
+        A.PiecewiseAffine,
+        {
+            "scale": 0.33,
+            "nb_rows": (10, 20),
+            "nb_cols": 33,
+            "interpolation": 2,
+            "mask_interpolation": 1,
+            "cval": 10,
+            "cval_mask": 20,
+            "mode": "edge",
+            "absolute_scale": True,
+            "keypoints_threshold": 0.1,
+        },
+    ],
+    [A.ChannelDropout, dict(channel_drop_range=(1, 2), fill_value=1)],
+    [A.ChannelShuffle, {}],
+    [A.Downscale, dict(scale_min=0.5, scale_max=0.75, interpolation=cv2.INTER_LINEAR)],
+    [A.Flip, {}],
+    [A.FromFloat, dict(dtype="uint8", max_value=1)],
+    [A.HorizontalFlip, {}],
+    [A.ISONoise, dict(color_shift=(0.2, 0.3), intensity=(0.7, 0.9))],
+    [A.InvertImg, {}],
+    [A.MaskDropout, dict(max_objects=2, image_fill_value=10, mask_fill_value=20)],
+    [A.NoOp, {}],
+    [A.RandomResizedCrop, dict(height=20, width=30, scale=(0.5, 0.6), ratio=(0.8, 0.9))],
+    [A.FancyPCA, dict(alpha=0.3)],
+    [A.RandomRotate90, {}],
+    [A.ToGray, {}],
+    [A.ToSepia, {}],
+    [A.Transpose, {}],
+    [A.VerticalFlip, {}],
+]
+
+AUGMENTATION_CLS_EXCEPT = {
+    A.FDA,
+    A.HistogramMatching,
+    A.PixelDistributionAdaptation,
+    A.Lambda,
+    A.RandomCropNearBBox,
+    A.RandomSizedBBoxSafeCrop,
+    A.GridDropout,
+    A.GlassBlur,
+    A.TemplateTransform,
+}
+
+
+@pytest.mark.parametrize(
+    ["augmentation_cls", "params"], check_all_augs_exists(AUGMENTATION_CLS_PARAMS, AUGMENTATION_CLS_EXCEPT)
 )
-
-
-@pytest.mark.parametrize(["augmentation_cls", "params"], *AUGMENTATION_CLS_PARAMS)
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
 @pytest.mark.parametrize("always_apply", (False, True))
@@ -348,7 +347,9 @@ def test_augmentations_serialization_with_custom_parameters(
     assert np.array_equal(aug_data["mask"], deserialized_aug_data["mask"])
 
 
-@pytest.mark.parametrize(["augmentation_cls", "params"], *AUGMENTATION_CLS_PARAMS)
+@pytest.mark.parametrize(
+    ["augmentation_cls", "params"], check_all_augs_exists(AUGMENTATION_CLS_PARAMS, AUGMENTATION_CLS_EXCEPT)
+)
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
 @pytest.mark.parametrize("always_apply", (False, True))
@@ -371,64 +372,35 @@ def test_augmentations_serialization_to_file_with_custom_parameters(
 
 @pytest.mark.parametrize(
     ["augmentation_cls", "params"],
-    [
-        [A.ImageCompression, {}],
-        [A.JpegCompression, {}],
-        [A.HueSaturationValue, {}],
-        [A.RGBShift, {}],
-        [A.RandomBrightnessContrast, {}],
-        [A.Blur, {}],
-        [A.MotionBlur, {}],
-        [A.MedianBlur, {}],
-        [A.GaussianBlur, {}],
-        [A.GaussNoise, {}],
-        [A.CLAHE, {}],
-        [A.ChannelShuffle, {}],
-        [A.InvertImg, {}],
-        [A.RandomGamma, {}],
-        [A.ToGray, {}],
-        [A.Cutout, {}],
-        [A.GaussNoise, {}],
-        [A.RandomSnow, {}],
-        [A.RandomRain, {}],
-        [A.RandomFog, {}],
-        [A.RandomSunFlare, {}],
-        [A.RandomShadow, {}],
-        [A.PadIfNeeded, {}],
-        [A.VerticalFlip, {}],
-        [A.HorizontalFlip, {}],
-        [A.Flip, {}],
-        [A.Transpose, {}],
-        [A.RandomRotate90, {}],
-        [A.Rotate, {}],
-        [A.SafeRotate, {}],
-        [A.ShiftScaleRotate, {}],
-        [A.CenterCrop, {"height": 10, "width": 10}],
-        [A.RandomCrop, {"height": 10, "width": 10}],
-        [A.RandomSizedCrop, {"min_max_height": (4, 8), "height": 10, "width": 10}],
-        [A.Crop, {"x_max": 64, "y_max": 64}],
-        [A.FromFloat, {}],
-        [A.ToFloat, {}],
-        [A.Normalize, {}],
-        [A.RandomBrightness, {}],
-        [A.RandomContrast, {}],
-        [A.RandomScale, {}],
-        [A.Resize, {"height": 64, "width": 64}],
-        [A.SmallestMaxSize, {}],
-        [A.LongestMaxSize, {}],
-        [A.RandomSizedBBoxSafeCrop, {"height": 50, "width": 50}],
-        [A.Solarize, {}],
-        [A.Posterize, {}],
-        [A.Equalize, {}],
-        [A.MultiplicativeNoise, {}],
-        [A.ColorJitter, {}],
-        [A.Perspective, {}],
-        [A.Sharpen, {}],
-        [A.Emboss, {}],
-        [A.Superpixels, {}],
-        [A.Affine, {}],
-        [A.PiecewiseAffine, {}],
-    ],
+    get_transforms(
+        custom_arguments={
+            A.Crop: {"y_min": 0, "y_max": 10, "x_min": 0, "x_max": 10},
+            A.CenterCrop: {"height": 10, "width": 10},
+            A.CropNonEmptyMaskIfExists: {"height": 10, "width": 10},
+            A.RandomCrop: {"height": 10, "width": 10},
+            A.RandomResizedCrop: {"height": 10, "width": 10},
+            A.RandomSizedCrop: {"min_max_height": (4, 8), "height": 10, "width": 10},
+            A.CropAndPad: {"px": 10},
+            A.Resize: {"height": 10, "width": 10},
+            A.RandomSizedBBoxSafeCrop: {"height": 10, "width": 10},
+        },
+        except_augmentations={
+            A.RandomCropNearBBox,
+            A.FDA,
+            A.HistogramMatching,
+            A.PixelDistributionAdaptation,
+            A.Lambda,
+            A.CoarseDropout,
+            A.CropNonEmptyMaskIfExists,
+            A.ElasticTransform,
+            A.GridDistortion,
+            A.RandomGridShuffle,
+            A.GridDropout,
+            A.MaskDropout,
+            A.OpticalDistortion,
+            A.TemplateTransform,
+        },
+    ),
 )
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
@@ -449,58 +421,35 @@ def test_augmentations_for_bboxes_serialization(
 
 @pytest.mark.parametrize(
     ["augmentation_cls", "params"],
-    [
-        [A.ImageCompression, {}],
-        [A.JpegCompression, {}],
-        [A.HueSaturationValue, {}],
-        [A.RGBShift, {}],
-        [A.RandomBrightnessContrast, {}],
-        [A.Blur, {}],
-        [A.MotionBlur, {}],
-        [A.MedianBlur, {}],
-        [A.GaussianBlur, {}],
-        [A.GaussNoise, {}],
-        [A.CLAHE, {}],
-        [A.ChannelShuffle, {}],
-        [A.InvertImg, {}],
-        [A.RandomGamma, {}],
-        [A.ToGray, {}],
-        [A.Cutout, {}],
-        [A.GaussNoise, {}],
-        [A.RandomSnow, {}],
-        [A.RandomRain, {}],
-        [A.RandomFog, {}],
-        [A.RandomSunFlare, {}],
-        [A.RandomShadow, {}],
-        [A.PadIfNeeded, {}],
-        [A.VerticalFlip, {}],
-        [A.HorizontalFlip, {}],
-        [A.Flip, {}],
-        [A.RandomRotate90, {}],
-        [A.Rotate, {}],
-        [A.SafeRotate, {}],
-        [A.ShiftScaleRotate, {}],
-        [A.CenterCrop, {"height": 10, "width": 10}],
-        [A.RandomCrop, {"height": 10, "width": 10}],
-        [A.RandomSizedCrop, {"min_max_height": (4, 8), "height": 10, "width": 10}],
-        [A.FromFloat, {}],
-        [A.ToFloat, {}],
-        [A.Normalize, {}],
-        [A.RandomBrightness, {}],
-        [A.RandomContrast, {}],
-        [A.RandomScale, {}],
-        [A.Solarize, {}],
-        [A.Posterize, {}],
-        [A.Equalize, {}],
-        [A.MultiplicativeNoise, {}],
-        [A.ColorJitter, {}],
-        [A.Perspective, {}],
-        [A.Sharpen, {}],
-        [A.Emboss, {}],
-        [A.Superpixels, {}],
-        [A.Affine, {}],
-        [A.PiecewiseAffine, {}],
-    ],
+    get_transforms(
+        custom_arguments={
+            A.Crop: {"y_min": 0, "y_max": 10, "x_min": 0, "x_max": 10},
+            A.CenterCrop: {"height": 10, "width": 10},
+            A.CropNonEmptyMaskIfExists: {"height": 10, "width": 10},
+            A.RandomCrop: {"height": 10, "width": 10},
+            A.RandomResizedCrop: {"height": 10, "width": 10},
+            A.RandomSizedCrop: {"min_max_height": (4, 8), "height": 10, "width": 10},
+            A.CropAndPad: {"px": 10},
+            A.Resize: {"height": 10, "width": 10},
+        },
+        except_augmentations={
+            A.RandomCropNearBBox,
+            A.FDA,
+            A.HistogramMatching,
+            A.PixelDistributionAdaptation,
+            A.Lambda,
+            A.CoarseDropout,
+            A.CropNonEmptyMaskIfExists,
+            A.ElasticTransform,
+            A.GridDistortion,
+            A.RandomGridShuffle,
+            A.GridDropout,
+            A.MaskDropout,
+            A.OpticalDistortion,
+            A.RandomSizedBBoxSafeCrop,
+            A.TemplateTransform,
+        },
+    ),
 )
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
@@ -677,48 +626,9 @@ def test_transform_pipeline_serialization_with_keypoints(seed, image, keypoints,
 
 @pytest.mark.parametrize(
     ["augmentation_cls", "params"],
-    [
-        [A.ChannelShuffle, {}],
-        [A.GaussNoise, {}],
-        [A.Cutout, {}],
-        [A.ImageCompression, {}],
-        [A.JpegCompression, {}],
-        [A.HueSaturationValue, {}],
-        [A.RGBShift, {}],
-        [A.RandomBrightnessContrast, {}],
-        [A.Blur, {}],
-        [A.MotionBlur, {}],
-        [A.MedianBlur, {}],
-        [A.CLAHE, {}],
-        [A.InvertImg, {}],
-        [A.RandomGamma, {}],
-        [A.ToGray, {}],
-        [A.VerticalFlip, {}],
-        [A.HorizontalFlip, {}],
-        [A.Flip, {}],
-        [A.Transpose, {}],
-        [A.RandomRotate90, {}],
-        [A.Rotate, {}],
-        [A.SafeRotate, {}],
-        [A.OpticalDistortion, {}],
-        [A.GridDistortion, {}],
-        [A.ElasticTransform, {}],
-        [A.Normalize, {}],
-        [A.ToFloat, {}],
-        [A.FromFloat, {}],
-        [A.RandomGridShuffle, {}],
-        [A.Solarize, {}],
-        [A.Posterize, {}],
-        [A.Equalize, {}],
-        [A.MultiplicativeNoise, {}],
-        [A.ColorJitter, {}],
-        [A.Perspective, {}],
-        [A.Sharpen, {}],
-        [A.Emboss, {}],
-        [A.RandomToneCurve, {}],
-        [A.CropAndPad, {"px": -12}],
-        [A.Superpixels, {}],
-    ],
+    get_image_only_transforms(
+        except_augmentations={A.HistogramMatching, A.FDA, A.PixelDistributionAdaptation, A.TemplateTransform},
+    ),
 )
 @pytest.mark.parametrize("seed", TEST_SEEDS)
 def test_additional_targets_for_image_only_serialization(augmentation_cls, params, image, seed):
@@ -849,3 +759,21 @@ def test_serialization_v2_to_dict():
 )
 def test_shorten_class_name(class_fullname, expected_short_class_name):
     assert shorten_class_name(class_fullname) == expected_short_class_name
+
+
+@pytest.mark.parametrize("seed", TEST_SEEDS)
+@pytest.mark.parametrize("p", [1])
+def test_template_transform_serialization(image, template, seed, p):
+    template_transform = A.TemplateTransform(name="template", templates=template, p=p)
+
+    aug = A.Compose([A.Flip(), template_transform, A.Blur()])
+
+    serialized_aug = A.to_dict(aug)
+    deserialized_aug = A.from_dict(serialized_aug, lambda_transforms={"template": template_transform})
+
+    set_seed(seed)
+    aug_data = aug(image=image)
+    set_seed(seed)
+    deserialized_aug_data = deserialized_aug(image=image)
+
+    assert np.array_equal(aug_data["image"], deserialized_aug_data["image"])
